summaryrefslogtreecommitdiffstats
path: root/src/occ_405/thread
diff options
context:
space:
mode:
authorWilliam Bryan <wilbryan@us.ibm.com>2015-10-02 10:26:02 -0500
committerWilliam A. Bryan <wilbryan@us.ibm.com>2015-10-07 16:11:33 -0500
commit4cf2e7f9cd54adba2dca1972407bffbfca719b36 (patch)
treef57e105b5e773a27bdfcbefc6db1401a9091ee02 /src/occ_405/thread
parent64ba6727bc31917105528e60950b0b2d2745a15e (diff)
downloadtalos-occ-4cf2e7f9cd54adba2dca1972407bffbfca719b36.tar.gz
talos-occ-4cf2e7f9cd54adba2dca1972407bffbfca719b36.zip
Enable command handler thread and misc cleanup
1. The command handler thread now starts running. 2. Disabled just about all of the command handler functions so that they can be enabled as they are implemented and needed. 3. Fixed a bug in the linker script where the response buffer is put in the incorrect offset. Change-Id: Ia169cb9fef3fd91d5667e636569ada9d83c02b3b Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/20927 Reviewed-by: William A. Bryan <wilbryan@us.ibm.com> Tested-by: William A. Bryan <wilbryan@us.ibm.com> Reviewed-by: Wael Elessawy <welessa@us.ibm.com>
Diffstat (limited to 'src/occ_405/thread')
-rwxr-xr-xsrc/occ_405/thread/threadSch.c13
-rwxr-xr-xsrc/occ_405/thread/thrm_thread.c7
2 files changed, 11 insertions, 9 deletions
diff --git a/src/occ_405/thread/thrm_thread.c b/src/occ_405/thread/thrm_thread.c
index 13d9423..b7a6100 100755
--- a/src/occ_405/thread/thrm_thread.c
+++ b/src/occ_405/thread/thrm_thread.c
@@ -83,6 +83,7 @@ uint8_t THRM_thread_get_cooling_request()
// End Function Specification
errlHndl_t thrm_thread_load_thresholds()
{
+/* TEMP -- THRM THREAD NOT YET ENABLED (NEED SENSOR / AMEC)
errlHndl_t l_err = NULL;
cmdh_thrm_thresholds_t *l_data = NULL;
uint8_t i = 0;
@@ -151,7 +152,7 @@ errlHndl_t thrm_thread_load_thresholds()
}while(0);
return(l_err);
-
+*/
}
@@ -329,6 +330,7 @@ BOOLEAN thrm_thread_vrm_fan_control(const uint16_t i_vrfan)
// End Function Specification
void thrm_thread_main()
{
+/* TEMP -- THRM THREAD NOT ENABLED YET (NEED SENSOR / AMEC)
errlHndl_t l_err = NULL;
BOOLEAN l_IncreaseFans = FALSE;
sensor_t *l_sensor = NULL;
@@ -432,7 +434,7 @@ void thrm_thread_main()
* @userdata4 OCC_NO_EXTENDED_RC
* @devdesc Request a fan increase and fan is already in full speed
*
- */
+ */ /*
l_err = createErrl(THRD_THERMAL_MAIN, //modId
FAN_FULL_SPEED, //reasoncode
OCC_NO_EXTENDED_RC, //Extended reason code
@@ -456,4 +458,5 @@ void thrm_thread_main()
}
}
}
+*/
}
OpenPOWER on IntegriCloud
diff --git a/src/occ_405/thread/threadSch.c b/src/occ_405/thread/threadSch.c
index 9261027..c91c91f 100755
--- a/src/occ_405/thread/threadSch.c
+++ b/src/occ_405/thread/threadSch.c
@@ -44,13 +44,13 @@ SsxTimer G_threadSchTimer;
// Index of highest priority thread in G_scheduledThreads
uint16_t G_threadSchedulerIndex = 0;
// TEMP: Commented out cmd handler and dcom threads for Simics enablement.
// Will need to reenable them when we need them again.
// Array that holds the threads that need scheduling
SsxThread* G_scheduledThreads[] =
{
&Main_thread,
-// &Cmd_Hndl_thread,
+ &Cmd_Hndl_thread,
&App_thread,
&TestAppletThread,
// &Dcom_thread,
@@ -149,14 +149,13 @@ void initThreadScheduler(void)
// threads in G_scheduledThreads ie highest priority thread should be
// index 0 of G_scheduledThreads
-/* TEMP -- NOT USED IN PHASE1
l_cmdThreadRc = createAndResumeThreadHelper(&Cmd_Hndl_thread,
Cmd_Hndl_thread_routine,
(void *)0,
(SsxAddress)Cmd_hndl_thread_stack,
THREAD_STACK_SIZE,
THREAD_PRIORITY_3);
-*/
+
l_appThreadRc = createAndResumeThreadHelper(&App_thread,
App_thread_routine,
(void *)&G_apltPdtType,
@@ -192,6 +191,7 @@ void initThreadScheduler(void)
{
TRAC_INFO("Error creating timer: RC: %d", l_timerRc);
}
+
/* TEMP -- NOT USED IN PHASE1
// Create snapshot timer
l_snapshotTimerRc = ssx_timer_create(&G_snapshotTimer, cmdh_snapshot_callback, 0);
@@ -220,12 +220,11 @@ void initThreadScheduler(void)
|| l_timerRc
|| l_snapshotTimerRc )
{
-// TEMP -- UNRESOLVED TRACE ERROR
-/* TRAC_ERR("Error creating thread: l_appThreadRc: %d, "
+ TRAC_ERR("Error creating thread: l_appThreadRc: %d, "
"l_testAppletThreadRc: %d, l_cmdThreadRc: %d, "
"l_dcomThreadRc: %d", l_appThreadRc,l_testAppletThreadRc,
l_timerRc,l_cmdThreadRc,l_dcomThreadRc);
-*/
+
TRAC_ERR("Error starting timers: timerRc: %d, snapshotTimerRc: %d.",
l_timerRc, l_snapshotTimerRc);
// Create error log and log it
@@ -44,13 +44,13 @@ SsxTimer G_threadSchTimer;
// Index of highest priority thread in G_scheduledThreads
uint16_t G_threadSchedulerIndex = 0;
-// TEMP: Commented out cmd handler and dcom threads for Simics enablement.
+// TEMP: Commented out dcom thread for Simics enablement.
// Will need to reenable them when we need them again.
// Array that holds the threads that need scheduling